from uniter.Uniter import Unit, __Q

class Speed(Unit[__Q]): pass

class FPS(Speed[Speed]): pass

class KMH(Speed[Speed]): pass

class LightSpeed(Speed[Speed]): pass

class MPH(Speed[Speed]): pass

class MS(Speed[Speed]): pass

