from uniter.Uniter import Unit, __Q

class Computer_Memory(Unit[__Q]): pass

class Bit(Computer_Memory[Computer_Memory]): pass

class Byte(Computer_Memory[Computer_Memory]): pass

class EB(Computer_Memory[Computer_Memory]): pass

class Eb(Computer_Memory[Computer_Memory]): pass

class GB(Computer_Memory[Computer_Memory]): pass

class Gb(Computer_Memory[Computer_Memory]): pass

class KB(Computer_Memory[Computer_Memory]): pass

class Kb(Computer_Memory[Computer_Memory]): pass

class MB(Computer_Memory[Computer_Memory]): pass

class Mb(Computer_Memory[Computer_Memory]): pass

class PB(Computer_Memory[Computer_Memory]): pass

class Pb(Computer_Memory[Computer_Memory]): pass

class TB(Computer_Memory[Computer_Memory]): pass

class Tb(Computer_Memory[Computer_Memory]): pass

class YB(Computer_Memory[Computer_Memory]): pass

class Yb(Computer_Memory[Computer_Memory]): pass

class ZB(Computer_Memory[Computer_Memory]): pass

class Zb(Computer_Memory[Computer_Memory]): pass

