from uniter.Uniter import Unit, __Q

class Volume(Unit[__Q]): pass

class CL(Volume[Volume]): pass

class CM_3(Volume[Volume]): pass

class DL(Volume[Volume]): pass

class DM_3(Volume[Volume]): pass

class HL(Volume[Volume]): pass

class L(Volume[Volume]): pass

class ML(Volume[Volume]): pass

class M_3(Volume[Volume]): pass

