from uniter.Uniter import Unit, __Q

class Area(Unit[__Q]): pass

class ARE(Area[Area]): pass

class CM_2(Area[Area]): pass

class DM_2(Area[Area]): pass

class HA(Area[Area]): pass

class KM_2(Area[Area]): pass

class MM_2(Area[Area]): pass

class M_2(Area[Area]): pass

